@@ -20,7 +20,6 @@
 
 #include "gtd-debug.h"
 #include "gtd-edit-pane.h"
-#include "gtd-empty-list-widget.h"
 #include "gtd-task-list-view.h"
 #include "gtd-task-list-view-model.h"
 #include "gtd-manager.h"
@@ -68,7 +67,7 @@ struct _GtdTaskListView
 {
   GtkBox                  parent;
 
-  GtdEmptyListWidget    *empty_list_widget;
+  AdwStatusPage         *empty_list_widget;
   GtkListBox            *listbox;
   GtkStack              *main_stack;
   GtkWidget             *scrolled_window;
@@ -200,7 +199,6 @@ update_empty_state (GtdTaskListView *self)
     return;
 
   is_empty = g_list_model_get_n_items (self->model) == 0;
-  gtd_empty_list_widget_set_is_empty (self->empty_list_widget, is_empty);
 
   show_empty_list_widget = !GTD_IS_TASK_LIST (self->model) &&
                            (is_empty || self->n_incomplete_tasks == 0);
@@ -260,7 +258,7 @@ on_incomplete_tasks_items_changed_cb (GListModel      *model,
 }
 
 static void
-on_empty_list_widget_add_tasks_cb (GtdEmptyListWidget *empty_list_widget,
+on_empty_list_widget_add_tasks_cb (AdwStatusPage      *empty_list_widget,
                                    GtdTaskListView    *self)
 {
   gtk_stack_set_visible_child_name (self->main_stack, "task-list");
@@ -288,6 +286,8 @@ create_row_for_task_cb (gpointer item,
 
   self = GTD_TASK_LIST_VIEW (user_data);
 
+  set_active_row (self, NULL);
+
   if (GTD_IS_TASK (item))
     {
       row = gtd_task_row_new (item, self->renderer);
@@ -426,17 +426,16 @@ static void
 on_remove_task_row_cb (GtdTaskRow      *row,
                        GtdTaskListView *self)
 {
+  GtdManager *manager = gtd_manager_get_default ();
   g_autofree gchar *text = NULL;
   GtdNotification *notification;
   RemoveTaskData *data;
   GtdTaskList *list;
-  GtdWindow *window;
   GtdTask *task;
 
   task = gtd_task_row_get_task (row);
 
   text = g_strdup_printf (_("Task <b>%s</b> removed"), gtd_task_get_title (task));
-  window = GTD_WINDOW (gtk_widget_get_root (GTK_WIDGET (self)));
 
   data = g_new0 (RemoveTaskData, 1);
   data->view = self;
@@ -447,19 +446,18 @@ on_remove_task_row_cb (GtdTaskRow      *row,
   gtd_task_list_remove_task (list, task);
 
   /* Notify about the removal */
-  notification = gtd_notification_new (text, 5000.0);
+  notification = gtd_notification_new (text);
 
-  gtd_notification_set_primary_action (notification,
-                                       (GtdNotificationActionFunc) on_remove_task_action_cb,
-                                       data);
+  gtd_notification_set_dismissal_action (notification,
+                                         (GtdNotificationActionFunc) on_remove_task_action_cb,
+                                         data);
 
   gtd_notification_set_secondary_action (notification,
                                          _("Undo"),
                                          (GtdNotificationActionFunc) on_undo_remove_task_action_cb,
                                          data);
 
-  gtd_window_notify (window, notification);
-
+  gtd_manager_send_notification (manager, notification);
 
   /* Clear the active row */
   set_active_row (self, NULL);
@@ -529,7 +527,7 @@ internal_header_func (GtkListBoxRow   *row,
     row_task = gtd_task_row_get_task (GTD_TASK_ROW (row));
 
   if (before)
-      before_task = gtd_task_row_get_task (GTD_TASK_ROW (row));
+      before_task = gtd_task_row_get_task (GTD_TASK_ROW (before));
 
   header = self->header_func (row_task, before_task, self->header_user_data);
 
@@ -696,6 +694,9 @@ on_drop_target_drag_motion_cb (GtkDropTarget   *drop_target,
 
   GTD_ENTRY;
 
+  /* Clear the currently active row */
+  set_active_row (self, NULL);
+
   drop = gtk_drop_target_get_current_drop (drop_target);
   drag = gdk_drop_get_drag (drop);
 
@@ -847,11 +848,14 @@ static void
 gtd_task_list_view_constructed (GObject *object)
 {
   GtdTaskListView *self = GTD_TASK_LIST_VIEW (object);
+  GdkTexture *texture = gdk_texture_new_from_resource ("/org/gnome/todo/ui/assets/all-done.svg");
   G_OBJECT_CLASS (gtd_task_list_view_parent_class)->constructed (object);
 
   /* action_group */
   self->action_group = G_ACTION_GROUP (g_simple_action_group_new ());
 
+  adw_status_page_set_paintable (self->empty_list_widget, GDK_PAINTABLE (texture));
+
   g_action_map_add_action_entries (G_ACTION_MAP (self->action_group),
                                    gtd_task_list_view_entries,
                                    G_N_ELEMENTS (gtd_task_list_view_entries),
@@ -899,7 +903,6 @@ gtd_task_list_view_class_init (GtdTaskListViewClass *klass)
   g_type_ensure (GTD_TYPE_EDIT_PANE);
   g_type_ensure (GTD_TYPE_NEW_TASK_ROW);
   g_type_ensure (GTD_TYPE_TASK_ROW);
-  g_type_ensure (GTD_TYPE_EMPTY_LIST_WIDGET);
 
   /**
    * GtdTaskListView::show-list-name:
@@ -1214,3 +1217,4 @@ gtd_task_list_view_set_default_date   (GtdTaskListView *self,
   g_clear_pointer (&self->default_date, g_date_time_unref);
   self->default_date = default_date ? g_date_time_ref (default_date) : NULL;
 }
+
